﻿using System;
using System.Drawing;
using System.Windows.Forms;

using Steema.TeeChart.Functions;
using Steema.TeeChart.Styles;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 라인 1 시리즈
        /// </summary>
        private Line line1;

        /// <summary>
        /// 스무딩 함수
        /// </summary>
        private Smoothing smoothing;

        /// <summary>
        /// 라인 2 시리즈
        /// </summary>
        private Line line2;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            #region 라인 1 시리즈를 생성한다.

            this.line1 = new Line();

            this.line1.Title                 = "line1";
            this.line1.Brush.Color           = Color.FromArgb(200, 230, 90 );
            this.line1.Color                 = Color.FromArgb(200, 230, 90 );
            this.line1.Pointer.Brush.Color   = Color.FromArgb(255, 255, 255);
            this.line1.Pointer.Brush.Solid   = true;
            this.line1.Pointer.Brush.Visible = true;
            this.line1.Pointer.HorizSize     = 3;
            this.line1.Pointer.VertSize      = 3;
            this.line1.Pointer.Style         = PointerStyles.Triangle;
            this.line1.Pointer.Pen.Color     = Color.FromArgb(255, 255, 0);
            this.line1.Pointer.Visible       = true;

            #endregion
            #region 스무딩 함수를 생성한다.

            this.smoothing = new Smoothing();

            this.smoothing.Interpolate = false;
            this.smoothing.Period      = 1d;

            #endregion
            #region 라인 2 시리즈를 생성한다.

            this.line2 = new Line();

            this.line2.Title       = "line2";
            this.line2.Brush.Color = Color.FromArgb(90, 150, 220);
            this.line2.Color       = Color.FromArgb(90, 150, 220);
            this.line2.DataSource  = this.line1;
            this.line2.Function    = this.smoothing;

            #endregion
            #region 티차트를 설정한다.

            this.tChart.Series.Add(this.line1);
            this.tChart.Series.Add(this.line2);

            #endregion
            #region 라인 1 시리즈를 설정한다.

            this.line1.Clear();

            this.line1.Add(new int[] { 4, 9, 5, 7, 2, 12, 15 });

            this.line1.RefreshSeries();

            #endregion

            this.showSourcePointerCheckBox.CheckedChanged += showSourcePointerCheckBox_CheckedChanged;
            this.showSourceCheckBox.CheckedChanged        += showSourceCheckBox_CheckedChanged;
            this.interpolationCheckBox.CheckedChanged     += interpolationCheckBox_CheckedChanged;
            this.factorNumericUpDown.ValueChanged         += factorNumericUpDown_ValueChanged;
            this.refreshButton.Click                      += refreshButton_Click;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 소스 포인터 표시 체크 박스 체크 변경시 처리하기 - showSourcePointerCheckBox_CheckedChanged(sender, e)

        /// <summary>
        /// 소스 포인터 표시 체크 박스 체크 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void showSourcePointerCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            this.line1.Pointer.Visible = this.showSourcePointerCheckBox.Checked;
        }

        #endregion
        #region 소스 표시 체크 박스 체크 변경시 처리하기 - showSourceCheckBox_CheckedChanged(sender, e)

        /// <summary>
        /// 소스 표시 체크 박스 체크 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void showSourceCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            this.line1.Visible = this.showSourceCheckBox.Checked;
        }

        #endregion
        #region 보전 체크 박스 체크 변경시 처리하기 - interpolationCheckBox_CheckedChanged(sender, e)

        /// <summary>
        /// 보전 체크 박스 체크 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void interpolationCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            this.smoothing.Interpolate = this.interpolationCheckBox.Checked;
        }

        #endregion
        #region 팩터 숫자 UP/DOWN 값 변경시 처리하기 - factorNumericUpDown_ValueChanged(sender, e)

        /// <summary>
        /// 팩터 숫자 UP/DOWN 값 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void factorNumericUpDown_ValueChanged(object sender, EventArgs e)
        {
            this.smoothing.Factor = (int)this.factorNumericUpDown.Value;
        }

        #endregion
        #region 갱신하기 버튼 클릭시 처리하기 - refreshButton_Click(sender, e)

        /// <summary>
        /// 갱신하기 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void refreshButton_Click(object sender, EventArgs e)
        {
            this.line1.FillSampleValues(10);
        }

        #endregion
    }
}